# eric7.Plugins.VcsPlugins.vcsMercurial.GpgExtension.HgGpgSignDialog

Module implementing a dialog to enter data for signing a revision.

### Global Attributes

None

### Classes

HgGpgSignDialog | Class implementing a dialog to enter data for signing a revision.

### Functions

None

## HgGpgSignDialog

Class implementing a dialog to enter data for signing a revision.

### Derived from

QDialog, Ui_HgGpgSignDialog

### Class Attributes

None

### Class Methods

None

### Methods

HgGpgSignDialog | Constructor
__updateOK | Private slot to update the OK button.
getData | Public method to retrieve the entered data.
on_bookmarkButton_toggled | Private slot to handle changes of the Bookmark select button.
on_bookmarkCombo_editTextChanged | Private slot to handle changes of the Bookmark combo.
on_branchButton_toggled | Private slot to handle changes of the Branch select button.
on_branchCombo_editTextChanged | Private slot to handle changes of the Branch combo.
on_idButton_toggled | Private slot to handle changes of the ID select button.
on_idEdit_textChanged | Private slot to handle changes of the ID edit.
on_tagButton_toggled | Private slot to handle changes of the Tag select button.
on_tagCombo_editTextChanged | Private slot to handle changes of the Tag combo.

### Static Methods

None

#### HgGpgSignDialog (Constructor)

HgGpgSignDialog(tagsList, branchesList, bookmarksList=None, parent=None)

Constructor

tagsList
  list of tags (list of strings)
branchesList
  list of branches (list of strings)
bookmarksList
  list of bookmarks (list of strings)
parent
  reference to the parent widget (QWidget)

#### HgGpgSignDialog.__updateOK

__updateOK()

Private slot to update the OK button.

#### HgGpgSignDialog.getData

getData()

Public method to retrieve the entered data.

Return:
  tuple giving the revision, a flag indicating not to commit the signature, a commit message, an ID of the key to be used, a flag indicating a local signature and a flag indicating a forced signature (string, boolean, string, string, boolean, boolean)

#### HgGpgSignDialog.on_bookmarkButton_toggled

on_bookmarkButton_toggled(checked)

Private slot to handle changes of the Bookmark select button.

checked
  state of the button (boolean)

#### HgGpgSignDialog.on_bookmarkCombo_editTextChanged

on_bookmarkCombo_editTextChanged(txt)

Private slot to handle changes of the Bookmark combo.

txt
  text of the combo (string)

#### HgGpgSignDialog.on_branchButton_toggled

on_branchButton_toggled(checked)

Private slot to handle changes of the Branch select button.

checked
  state of the button (boolean)

#### HgGpgSignDialog.on_branchCombo_editTextChanged

on_branchCombo_editTextChanged(txt)

Private slot to handle changes of the Branch combo.

txt
  text of the combo (string)

#### HgGpgSignDialog.on_idButton_toggled

on_idButton_toggled(checked)

Private slot to handle changes of the ID select button.

checked
  state of the button (boolean)

#### HgGpgSignDialog.on_idEdit_textChanged

on_idEdit_textChanged(txt)

Private slot to handle changes of the ID edit.

txt
  text of the edit (string)

#### HgGpgSignDialog.on_tagButton_toggled

on_tagButton_toggled(checked)

Private slot to handle changes of the Tag select button.

checked
  state of the button (boolean)

#### HgGpgSignDialog.on_tagCombo_editTextChanged

on_tagCombo_editTextChanged(txt)

Private slot to handle changes of the Tag combo.

txt
  text of the combo (string)

Up